@@ -8,6 +8,8 @@ from .entities import Folder, Event
 this = Path(__file__)
 logger = logging.getLogger(f"logger.{this.stem}")
 
+__all__ = ['Listener', 'NewFolderListener', 'UploadListener']
+
 
 class Listener:
     def __init__(
@@ -82,3 +84,37 @@ class Listener:
                 callback(
                     event
                 )
+
+
+class NewFolderListener(Listener):
+    def __init__(
+            self,
+            folder: Union[Folder, str],
+            sql_path: Path,
+            callback: Callable[[Event], None] = None,
+            is_deep: bool = False
+    ):
+        super().__init__(
+            folder,
+            sql_path,
+            activity='new_folder',
+            is_deep=is_deep,
+            callback=callback
+        )
+
+
+class UploadListener(Listener):
+    def __init__(
+            self,
+            folder: Union[Folder, str],
+            sql_path: Path,
+            callback: Callable[[Event], None] = None,
+            is_deep: bool = True
+    ):
+        super().__init__(
+            folder,
+            sql_path,
+            activity='upload',
+            is_deep=is_deep,
+            callback=callback
+        )
\ No newline at end of file
